summaryrefslogtreecommitdiff
path: root/hints
diff options
context:
space:
mode:
authorJarkko Hietaniemi <jhi@iki.fi>2000-03-02 17:48:15 +0000
committerJarkko Hietaniemi <jhi@iki.fi>2000-03-02 17:48:15 +0000
commit8a647129b625da7b991d7050849bf1dc6684f30c (patch)
tree7af5991074fe6825feda4d328f8e62228391341b /hints
parent400e3f8e5f6208355b1b7b8eff6eed4e7f1231eb (diff)
downloadperl-8a647129b625da7b991d7050849bf1dc6684f30c.tar.gz
Confusion over uselargefiles.cbu and uselfs.cbu (the first one
is the correct one), spotted by Robin Barker. p4raw-id: //depot/cfgperl@5440
Diffstat (limited to 'hints')
-rw-r--r--hints/aix.sh7
-rw-r--r--hints/hpux.sh4
2 files changed, 6 insertions, 5 deletions
diff --git a/hints/aix.sh b/hints/aix.sh
index 5a9482002c..d679ba9ee8 100644
--- a/hints/aix.sh
+++ b/hints/aix.sh
@@ -201,9 +201,9 @@ EOM
esac
EOCBU
# This script UU/uselfs.cbu will get 'called-back' by Configure
# after it has prompted the user for whether to use large files.
-cat > UU/uselfs.cbu <<'EOCBU'
+cat > UU/uselargefiles.cbu <<'EOCBU'
case "$uselargefiles" in
''|$define|true|[yY]*)
lfcflags="`getconf XBS5_ILP32_OFFBIG_CFLAGS 2>/dev/null`"
@@ -311,7 +311,8 @@ EOM
# do any harm, I didn't pursue it. -- sh
lfldflags="`echo $lfldflags`"
lflibs="`getconf XBS5_LP64_OFF64_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
# -q32 and -b32 may have been set by uselfs or user. Remove them.
ccflags="`echo $ccflags | sed -e 's@-q32@@'`"
ldflags="`echo $ldflags | sed -e 's@-b32@@'`"
# Tell archiver to use large format. Unless we remove 'ar'
@@ -201,9 +201,9 @@ EOM
esac
EOCBU
-# This script UU/uselfs.cbu will get 'called-back' by Configure
+# This script UU/uselargefiles.cbu will get 'called-back' by Configure
# after it has prompted the user for whether to use large files.
@@ -311,7 +311,8 @@ EOM
lfldflags="`echo $lfldflags`"
lflibs="`getconf XBS5_LP64_OFF64_LIBS 2>/dev/null|sed -e 's@^-l@@' -e 's@ -l@ @g`"
- # -q32 and -b32 may have been set by uselfs or user. Remove them.
+ # -q32 and -b32 may have been set by uselargefiles or user.
+ # Remove them.
ccflags="`echo $ccflags | sed -e 's@-q32@@'`"
ldflags="`echo $ldflags | sed -e 's@-b32@@'`"
diff --git a/hints/hpux.sh b/hints/hpux.sh
index faf5879ed9..bbb91f7894 100644
--- a/hints/hpux.sh
+++ b/hints/hpux.sh
@@ -378,8 +378,8 @@ EOM
;;
esac
-cat > UU/uselfs.cbu <<'EOCBU'
-# This script UU/uselfs.cbu will get 'called-back' by Configure
+cat > UU/uselargefiles.cbu <<'EOCBU'
+# This script UU/uselargefiles.cbu will get 'called-back' by Configure
# after it has prompted the user for whether to use large files.
case "$uselargefiles" in
''|$define|true|[yY]*)